@@ -7,18 +7,17 @@ import contextlib
 import json
 import logging
 import signal
-from datetime import datetime
 from pathlib import Path
-from typing import TYPE_CHECKING, Annotated
+from typing import Annotated
 
 import typer
+from prompt_toolkit import PromptSession
+from prompt_toolkit.patch_stdout import patch_stdout
 from rich.console import Console
 
+from chzzk.cli import timezone as tz
 from chzzk.cli.formatter import ChatFormatter, FormatConfig
-from chzzk.cli.logging import setup_logging
-from chzzk.cli.tui import can_run_tui, run_tui
-from chzzk.cli.tui.apps import ChatViewerApp, InteractiveChatApp
-from chzzk.cli.writers import ChatWriter, OutputFormat, create_writer
+from chzzk.cli.writers import ChatWriter, OutputFormat, create_writer, generate_chat_log_filename
 from chzzk.constants import StatusText
 from chzzk.exceptions import ChatConnectionError, ChatNotLiveError
 from chzzk.unofficial import (
@@ -29,22 +28,14 @@ from chzzk.unofficial import (
 )
 from chzzk.unofficial.models.reconnect import ReconnectEvent, ReconnectReason, StatusChangeEvent
 
-if TYPE_CHECKING:
-    from chzzk.cli.config import ConfigManager
-
 app = typer.Typer(no_args_is_help=True)
 console = Console()
 logger = logging.getLogger("chzzk.cli.chat")
 
 
-def get_config(ctx: typer.Context) -> ConfigManager:
-    """Get ConfigManager from context."""
-    return ctx.obj["config"]
-
-
 def get_auth_cookies(ctx: typer.Context) -> tuple[str | None, str | None]:
     """Get authentication cookies from context."""
-    config = get_config(ctx)
+    config = ctx.obj["config"]
     return config.get_auth_cookies(
         cli_nid_aut=ctx.obj.get("nid_aut"),
         cli_nid_ses=ctx.obj.get("nid_ses"),
@@ -66,7 +57,7 @@ def format_chat_message_json(msg: ChatMessage) -> str:
     return json.dumps(
         {
             "type": "chat",
-            "timestamp": datetime.now().isoformat(),
+            "timestamp": tz.now().isoformat(),
             "user_id_hash": msg.user_id_hash,
             "nickname": msg.nickname,
             "content": msg.content,
@@ -80,7 +71,7 @@ def format_donation_message_json(msg: DonationMessage) -> str:
     return json.dumps(
         {
             "type": "donation",
-            "timestamp": datetime.now().isoformat(),
+            "timestamp": tz.now().isoformat(),
             "user_id_hash": msg.user_id_hash,
             "nickname": msg.nickname,
             "content": msg.content,
@@ -94,7 +85,7 @@ def format_sent_message_json(content: str) -> str:
     return json.dumps(
         {
             "type": "sent",
-            "timestamp": datetime.now().isoformat(),
+            "timestamp": tz.now().isoformat(),
             "content": content,
         }
     )
@@ -114,13 +105,6 @@ def watch(
             help="Connect to chat even when channel is offline",
         ),
     ] = False,
-    no_tui: Annotated[
-        bool,
-        typer.Option(
-            "--no-tui",
-            help="Disable TUI and use simple console output",
-        ),
-    ] = False,
     output: Annotated[
         Path | None,
         typer.Option(
@@ -138,23 +122,52 @@ def watch(
             help="Output format: jsonl, txt (default: jsonl)",
         ),
     ] = "jsonl",
+    output_dir: Annotated[
+        Path | None,
+        typer.Option(
+            "--output-dir",
+            "-d",
+            envvar="CHZZK_CHAT_OUTPUT_DIR",
+            help="Directory to save chat logs (auto-generates filename based on stream info)",
+        ),
+    ] = None,
+    poll_interval: Annotated[
+        float,
+        typer.Option(
+            "--poll-interval",
+            envvar="CHZZK_POLL_INTERVAL",
+            help="Interval for polling live status in seconds (default: 10)",
+        ),
+    ] = 10.0,
+    auto_reconnect: Annotated[
+        bool,
+        typer.Option(
+            "--auto-reconnect/--no-auto-reconnect",
+            envvar="CHZZK_AUTO_RECONNECT",
+            help="Enable/disable automatic reconnection when stream restarts",
+        ),
+    ] = True,
 ) -> None:
     """Watch real-time chat messages from a channel.
 
     By default, only connects when the channel is live.
     Use --offline to connect to chat even when offline.
 
-    By default, displays a full-screen TUI with scrollable messages.
-    Use --no-tui for simple console output.
-
     Use --output to save messages to a file while watching.
+    Use --output-dir to auto-generate filename based on stream info.
     """
     nid_aut, nid_ses = get_auth_cookies(ctx)
     json_output = ctx.obj.get("json_output", False)
-    config = get_config(ctx)
     format_config = get_format_config(ctx)
 
-    # Create writer if output path specified
+    # Validate mutually exclusive options
+    if output and output_dir:
+        console.print(
+            "[red]Error:[/red] --output and --output-dir are mutually exclusive. Use only one."
+        )
+        raise typer.Exit(1)
+
+    # Create writer if output path specified (output_dir is handled inside _run_watch_console)
     writer: ChatWriter | None = None
     if output:
         try:
@@ -167,35 +180,6 @@ def watch(
             raise typer.Exit(1) from None
 
     try:
-        # Use TUI if available and not disabled/json mode
-        if not json_output and not no_tui and can_run_tui():
-            # Reconfigure logging for TUI mode: disable console output to prevent
-            # logs from corrupting the TUI display, keep file logging if configured
-            setup_logging(
-                ctx.obj.get("log_level", "WARNING"),
-                log_file=ctx.obj.get("log_file"),
-                disable_console=True,
-            )
-
-            viewer_app = ChatViewerApp(
-                config=config,
-                channel_id=channel_id,
-                nid_aut=nid_aut,
-                nid_ses=nid_ses,
-                allow_offline=offline,
-                writer=writer,
-                format_config=format_config,
-            )
-            run_tui(viewer_app)
-
-            if viewer_app.error_message:
-                console.print(f"[red]Error:[/red] {viewer_app.error_message}")
-                raise typer.Exit(1)
-            return
-
-        # Fallback to console output
-        if not no_tui and not json_output:
-            logger.info("TUI mode unavailable, using console mode")
         _run_watch_console(
             channel_id=channel_id,
             nid_aut=nid_aut,
@@ -204,6 +188,10 @@ def watch(
             json_output=json_output,
             writer=writer,
             format_config=format_config,
+            output_dir=output_dir,
+            output_format=OutputFormat(output_format),
+            poll_interval=poll_interval,
+            auto_reconnect=auto_reconnect,
         )
     finally:
         if writer:
@@ -219,13 +207,22 @@ def _run_watch_console(
     json_output: bool,
     writer: ChatWriter | None = None,
     format_config: FormatConfig | None = None,
+    output_dir: Path | None = None,
+    output_format: OutputFormat = OutputFormat.JSONL,
+    poll_interval: float = 10.0,
+    auto_reconnect: bool = True,
 ) -> None:
     """Run chat watch with console output (fallback mode)."""
     formatter = ChatFormatter(format_config)
+    # Track writer created from output_dir (needs to be closed on exit)
+    output_dir_writer: ChatWriter | None = None
 
     async def run_chat() -> None:
         async with AsyncUnofficialChzzkClient(nid_aut=nid_aut, nid_ses=nid_ses) as client:
-            chat = client.create_chat_client()
+            chat = client.create_chat_client(
+                auto_reconnect=auto_reconnect,
+                poll_interval=poll_interval,
+            )
 
             @chat.on_chat
             async def handle_chat(msg: ChatMessage) -> None:
@@ -318,6 +315,26 @@ def _run_watch_console(
                     console.print(f"[red]Error:[/red] {e}")
                 raise typer.Exit(1) from None
 
+            # Create writer from output_dir if specified (after getting live_detail)
+            nonlocal writer, output_dir_writer
+            if output_dir and not writer:
+                try:
+                    output_dir.mkdir(parents=True, exist_ok=True)
+                    output_path = generate_chat_log_filename(
+                        output_dir=output_dir,
+                        channel_id=channel_id,
+                        live_id=live_detail.live_id,
+                        open_date=live_detail.open_date,
+                        format=output_format,
+                    )
+                    output_dir_writer = create_writer(output_path, output_format)
+                    writer = output_dir_writer
+                    if not json_output:
+                        console.print(f"[dim]Saving chat to: {output_path}[/dim]")
+                except OSError as e:
+                    console.print(f"[red]Error:[/red] Cannot write to {output_dir}: {e}")
+                    raise typer.Exit(1) from None
+
             # Connect to chat
             try:
                 if not json_output:
@@ -381,8 +398,12 @@ def _run_watch_console(
                 if not json_output:
                     console.print("\n[yellow]Disconnected[/yellow]")
 
-    with contextlib.suppress(KeyboardInterrupt):
-        asyncio.run(run_chat())
+    try:
+        with contextlib.suppress(KeyboardInterrupt):
+            asyncio.run(run_chat())
+    finally:
+        if output_dir_writer:
+            output_dir_writer.close()
 
 
 @app.command()
@@ -411,13 +432,6 @@ def send(
             help="Interactive chat mode (send and receive messages)",
         ),
     ] = False,
-    no_tui: Annotated[
-        bool,
-        typer.Option(
-            "--no-tui",
-            help="Disable TUI and use simple console input/output",
-        ),
-    ] = False,
     output: Annotated[
         Path | None,
         typer.Option(
@@ -435,6 +449,31 @@ def send(
             help="Output format: jsonl, txt (default: jsonl)",
         ),
     ] = "jsonl",
+    output_dir: Annotated[
+        Path | None,
+        typer.Option(
+            "--output-dir",
+            "-d",
+            envvar="CHZZK_CHAT_OUTPUT_DIR",
+            help="Directory to save chat logs (interactive mode only, auto-generates filename)",
+        ),
+    ] = None,
+    poll_interval: Annotated[
+        float,
+        typer.Option(
+            "--poll-interval",
+            envvar="CHZZK_POLL_INTERVAL",
+            help="Interval for polling live status in seconds (default: 10)",
+        ),
+    ] = 10.0,
+    auto_reconnect: Annotated[
+        bool,
+        typer.Option(
+            "--auto-reconnect/--no-auto-reconnect",
+            envvar="CHZZK_AUTO_RECONNECT",
+            help="Enable/disable automatic reconnection when stream restarts",
+        ),
+    ] = True,
 ) -> None:
     """Send a chat message to a channel.
 
@@ -444,14 +483,11 @@ def send(
     a persistent connection where you can send and receive messages.
     Use --offline to connect even when the channel is offline.
 
-    In interactive mode, displays a full-screen TUI by default.
-    Use --no-tui for simple console input/output.
-
     Use --output to save messages to a file (interactive mode only).
+    Use --output-dir to auto-generate filename based on stream info (interactive mode only).
     """
     nid_aut, nid_ses = get_auth_cookies(ctx)
     json_output = ctx.obj.get("json_output", False)
-    config = get_config(ctx)
     format_config = get_format_config(ctx)
 
     if not nid_aut or not nid_ses:
@@ -475,13 +511,27 @@ def send(
             )
         raise typer.Exit(1)
 
-    # Warn if output is specified in non-interactive mode
+    # Validate mutually exclusive options
+    if output and output_dir:
+        console.print(
+            "[red]Error:[/red] --output and --output-dir are mutually exclusive. Use only one."
+        )
+        raise typer.Exit(1)
+
+    # Warn if output/output_dir is specified in non-interactive mode
     if output and not interactive:
         if not json_output:
             console.print("[yellow]Warning:[/yellow] --output is ignored in non-interactive mode.")
         output = None
+    if output_dir and not interactive:
+        if not json_output:
+            console.print(
+                "[yellow]Warning:[/yellow] --output-dir is ignored in non-interactive mode."
+            )
+        output_dir = None
 
     # Create writer if output path specified (interactive mode only)
+    # output_dir is handled inside _run_interactive_chat_console
     writer: ChatWriter | None = None
     if output:
         try:
@@ -495,38 +545,7 @@ def send(
 
     try:
         if interactive:
-            # Use TUI if available and not disabled/json mode
-            if not json_output and not no_tui and can_run_tui():
-                # Reconfigure logging for TUI mode: disable console output to prevent
-                # logs from corrupting the TUI display, keep file logging if configured
-                setup_logging(
-                    ctx.obj.get("log_level", "WARNING"),
-                    log_file=ctx.obj.get("log_file"),
-                    disable_console=True,
-                )
-
-                interactive_app = InteractiveChatApp(
-                    config=config,
-                    channel_id=channel_id,
-                    nid_aut=nid_aut,
-                    nid_ses=nid_ses,
-                    allow_offline=offline,
-                    writer=writer,
-                    format_config=format_config,
-                )
-                run_tui(interactive_app)
-
-                if interactive_app.error_message:
-                    console.print(f"[red]Error:[/red] {interactive_app.error_message}")
-                    raise typer.Exit(1)
-                return
-
-            # Fallback to console interactive mode
-            if not no_tui and not json_output:
-                logger.info("TUI mode unavailable, using console mode")
             _run_interactive_chat_console(
-                ctx=ctx,
-                config=config,
                 channel_id=channel_id,
                 nid_aut=nid_aut,
                 nid_ses=nid_ses,
@@ -534,6 +553,10 @@ def send(
                 json_output=json_output,
                 writer=writer,
                 format_config=format_config,
+                output_dir=output_dir,
+                output_format=OutputFormat(output_format),
+                poll_interval=poll_interval,
+                auto_reconnect=auto_reconnect,
             )
         else:
             # message is guaranteed to be non-None here (checked above)
@@ -610,8 +633,6 @@ def _send_single_message(
 
 def _run_interactive_chat_console(
     *,
-    ctx: typer.Context,
-    config: ConfigManager,
     channel_id: str,
     nid_aut: str,
     nid_ses: str,
@@ -619,144 +640,181 @@ def _run_interactive_chat_console(
     json_output: bool,
     writer: ChatWriter | None = None,
     format_config: FormatConfig | None = None,
+    output_dir: Path | None = None,
+    output_format: OutputFormat = OutputFormat.JSONL,
+    poll_interval: float = 10.0,
+    auto_reconnect: bool = True,
 ) -> None:
-    """Run interactive chat with console input/output (fallback mode).
+    """Run interactive chat with console input/output.
 
-    For non-JSON mode, uses Textual inline mode for proper cancellation.
-    For JSON mode, uses async stdin reading with timeout on cancellation.
-    """
-    if not json_output:
-        # Reconfigure logging for inline TUI mode: disable console output to prevent
-        # logs from corrupting the TUI display, keep file logging if configured
-        setup_logging(
-            ctx.obj.get("log_level", "WARNING"),
-            log_file=ctx.obj.get("log_file"),
-            disable_console=True,
-        )
-
-        # Use inline Textual app for non-JSON mode - this allows proper cancellation
-        interactive_app = InteractiveChatApp(
-            config=config,
-            channel_id=channel_id,
-            nid_aut=nid_aut,
-            nid_ses=nid_ses,
-            allow_offline=offline,
-            inline_mode=True,
-            writer=writer,
-            format_config=format_config,
-        )
-        run_tui(interactive_app, inline=True, inline_height=15)
-
-        if interactive_app.error_message:
-            console.print(f"[red]Error:[/red] {interactive_app.error_message}")
-            raise typer.Exit(1)
-        return
-
-    # JSON mode uses async stdin reading
-    _run_interactive_chat_json(
-        channel_id=channel_id,
-        nid_aut=nid_aut,
-        nid_ses=nid_ses,
-        offline=offline,
-        writer=writer,
-    )
-
-
-def _run_interactive_chat_json(
-    *,
-    channel_id: str,
-    nid_aut: str,
-    nid_ses: str,
-    offline: bool,
-    writer: ChatWriter | None = None,
-) -> None:
-    """Run interactive chat with JSON output (no TUI).
-
-    Uses asyncio.to_thread(input) with timeout on cancellation.
+    Uses async stdin reading with chat message display.
     """
+    formatter = ChatFormatter(format_config)
+    # Track writer created from output_dir (needs to be closed on exit)
+    output_dir_writer: ChatWriter | None = None
 
     async def run_chat() -> None:
         async with AsyncUnofficialChzzkClient(nid_aut=nid_aut, nid_ses=nid_ses) as client:
-            chat = client.create_chat_client()
+            chat = client.create_chat_client(
+                auto_reconnect=auto_reconnect,
+                poll_interval=poll_interval,
+            )
 
             @chat.on_chat
             async def handle_chat(msg: ChatMessage) -> None:
-                console.print(format_chat_message_json(msg))
+                if json_output:
+                    console.print(format_chat_message_json(msg))
+                else:
+                    console.print(formatter.format_chat(msg))
                 if writer:
                     writer.write_chat(msg)
 
             @chat.on_donation
             async def handle_donation(msg: DonationMessage) -> None:
-                console.print(format_donation_message_json(msg))
+                if json_output:
+                    console.print(format_donation_message_json(msg))
+                else:
+                    console.print(formatter.format_donation(msg))
                 if writer:
                     writer.write_donation(msg)
 
             @chat.on_live
             async def handle_live(event: StatusChangeEvent) -> None:
-                console.print(
-                    json.dumps(
-                        {
-                            "event": "live",
-                            "live_id": event.live_id,
-                            "title": event.live_title,
-                        }
+                if json_output:
+                    console.print(
+                        json.dumps(
+                            {
+                                "event": "live",
+                                "live_id": event.live_id,
+                                "title": event.live_title,
+                            }
+                        )
                     )
-                )
+                else:
+                    title = event.live_title or "제목 없음"
+                    console.print(f"\n[green]방송이 시작되었습니다![/green] {title}")
 
             @chat.on_offline
             async def handle_offline(event: StatusChangeEvent) -> None:
-                console.print(
-                    json.dumps(
-                        {
-                            "event": "offline",
-                            "live_id": event.live_id,
-                            "title": event.live_title,
-                        }
+                if json_output:
+                    console.print(
+                        json.dumps(
+                            {
+                                "event": "offline",
+                                "live_id": event.live_id,
+                                "title": event.live_title,
+                            }
+                        )
+                    )
+                else:
+                    console.print(
+                        "\n[yellow]방송이 종료되었습니다.[/yellow] "
+                        "재시작을 기다리는 중... (Ctrl+C로 종료)"
                     )
-                )
 
             @chat.on_reconnect
             async def handle_reconnect(event: ReconnectEvent) -> None:
-                console.print(
-                    json.dumps(
-                        {
-                            "event": "reconnect",
-                            "reason": event.reason.value,
-                            "old_chat_channel_id": event.old_chat_channel_id,
-                            "new_chat_channel_id": event.new_chat_channel_id,
-                        }
+                if json_output:
+                    console.print(
+                        json.dumps(
+                            {
+                                "event": "reconnect",
+                                "reason": event.reason.value,
+                                "old_chat_channel_id": event.old_chat_channel_id,
+                                "new_chat_channel_id": event.new_chat_channel_id,
+                            }
+                        )
                     )
-                )
+                else:
+                    if event.reason == ReconnectReason.STREAM_RESTARTED:
+                        console.print("[green]채팅에 다시 연결되었습니다.[/green]\n")
+                    else:
+                        console.print(
+                            "[yellow]채팅 채널이 변경되어 다시 연결되었습니다.[/yellow]\n"
+                        )
 
             @chat.on_reconnect_error
             async def handle_reconnect_error(error: Exception) -> None:
-                console.print(json.dumps({"event": "reconnect_error", "error": str(error)}))
+                if json_output:
+                    console.print(json.dumps({"event": "reconnect_error", "error": str(error)}))
+                else:
+                    console.print(f"[red]재연결 실패:[/red] {error}")
 
             # Get live detail first to check status (validates channel exists)
             try:
-                await client.live.get_live_detail(channel_id)
+                live_detail = await client.live.get_live_detail(channel_id)
             except Exception as e:
                 logger.error(f"Failed to get live detail: {e}")
-                console.print(json.dumps({"error": str(e)}))
+                if json_output:
+                    console.print(json.dumps({"error": str(e)}))
+                else:
+                    console.print(f"[red]Error:[/red] {e}")
                 raise typer.Exit(1) from None
 
+            # Create writer from output_dir if specified (after getting live_detail)
+            nonlocal writer, output_dir_writer
+            if output_dir and not writer:
+                try:
+                    output_dir.mkdir(parents=True, exist_ok=True)
+                    output_path = generate_chat_log_filename(
+                        output_dir=output_dir,
+                        channel_id=channel_id,
+                        live_id=live_detail.live_id,
+                        open_date=live_detail.open_date,
+                        format=output_format,
+                    )
+                    output_dir_writer = create_writer(output_path, output_format)
+                    writer = output_dir_writer
+                    if not json_output:
+                        console.print(f"[dim]Saving chat to: {output_path}[/dim]")
+                except OSError as e:
+                    console.print(f"[red]Error:[/red] Cannot write to {output_dir}: {e}")
+                    raise typer.Exit(1) from None
+
             # Connect to chat
             try:
+                if not json_output:
+                    status_text = StatusText.LIVE if live_detail.is_live else StatusText.OFFLINE
+                    console.print(
+                        f"[green]Connecting to chat...[/green] "
+                        f"({live_detail.channel_name or channel_id} - {status_text})"
+                    )
+
                 await chat.connect(channel_id, allow_offline=offline)
+
+                if not json_output:
+                    console.print(
+                        f"[green]Connected![/green] Interactive chat for "
+                        f"[cyan]{live_detail.channel_name or channel_id}[/cyan]"
+                    )
+                    console.print(
+                        "[dim]Type messages and press Enter to send. Ctrl+C to exit.[/dim]\n"
+                    )
+
             except ChatNotLiveError:
-                console.print(
-                    json.dumps(
-                        {
-                            "error": "Channel is not live",
-                            "channel_id": channel_id,
-                            "hint": "Use --offline to connect anyway",
-                        }
+                if json_output:
+                    console.print(
+                        json.dumps(
+                            {
+                                "error": "Channel is not live",
+                                "channel_id": channel_id,
+                                "hint": "Use --offline to connect anyway",
+                            }
+                        )
+                    )
+                else:
+                    console.print(
+                        f"[yellow]Channel {channel_id} is not live.[/yellow]\n"
+                        f"Use [cyan]--offline[/cyan] to connect to chat anyway."
                     )
-                )
                 raise typer.Exit(1) from None
+
             except ChatConnectionError as e:
                 logger.error(f"Failed to connect to chat: {e}")
-                console.print(json.dumps({"error": str(e)}))
+                if json_output:
+                    console.print(json.dumps({"error": str(e)}))
+                else:
+                    console.print(f"[red]Connection error:[/red] {e}")
                 raise typer.Exit(1) from None
 
             # Handle graceful shutdown
@@ -772,19 +830,26 @@ def _run_interactive_chat_json(
 
             # Input loop for sending messages
             async def input_loop() -> None:
+                session: PromptSession[str] = PromptSession()
                 while not stop_event.is_set():
                     try:
-                        line = await asyncio.to_thread(input)
+                        with patch_stdout(raw=True):
+                            line = await session.prompt_async("")
                         if line and not stop_event.is_set():
                             await chat.send_message(line)
-                            console.print(format_sent_message_json(line))
+                            if json_output:
+                                console.print(format_sent_message_json(line))
+                            else:
+                                console.print(formatter.format_sent(line))
                             if writer:
                                 writer.write_sent(line)
-                    except EOFError:
-                        # stdin closed
+                    except (EOFError, KeyboardInterrupt):
+                        # prompt_toolkit catches SIGINT and raises KeyboardInterrupt
+                        # We need to trigger shutdown here as well
+                        stop_event.set()
+                        chat.stop()
                         break
-                    except Exception:
-                        # Input interrupted (likely by signal)
+                    except asyncio.CancelledError:
                         break
 
             input_task = asyncio.create_task(input_loop())
@@ -795,9 +860,14 @@ def _run_interactive_chat_json(
                 pass
             finally:
                 input_task.cancel()
-                # Use timeout to avoid blocking on the uncancellable input() thread
-                with contextlib.suppress(asyncio.CancelledError, TimeoutError):
-                    await asyncio.wait_for(input_task, timeout=0.1)
+                with contextlib.suppress(asyncio.CancelledError):
+                    await input_task
+                if not json_output:
+                    console.print("\n[yellow]Disconnected[/yellow]")
 
-    with contextlib.suppress(KeyboardInterrupt):
-        asyncio.run(run_chat())
+    try:
+        with contextlib.suppress(KeyboardInterrupt):
+            asyncio.run(run_chat())
+    finally:
+        if output_dir_writer:
+            output_dir_writer.close()
